@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-VERSION = (3, 2, 0)
+VERSION = (3, 2, 1)
 
 
 def get_version(version):
@@ -18,9 +18,3 @@ def get_version(version):
 
 
 __version__ = get_version(VERSION)
-
-try:
-    default_app_config = 'django_extensions.apps.DjangoExtensionsConfig'
-except ModuleNotFoundError:
-    # this part is useful for allow setup.py to be used for version checks
-    pass
