@@ -1,4 +1,4 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 import sys
 
 from django.core.management.base import BaseCommand
@@ -47,7 +47,7 @@ class LoggingBaseCommand(BaseCommand):
 
     def execute(self, *args, **options):
         try:
-            super(LoggingBaseCommand, self).execute(*args, **options)
+            super().execute(*args, **options)
         except Exception as e:
             logger.error(e, exc_info=sys.exc_info(), extra={'status_code': 500})
             raise
