@@ -1,10 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
 
 
 force_color_support = mock.patch('django.core.management.color.supports_color', autospec=True, side_effect=lambda: True)
