@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
 import os
 import re
-import six
-import django
 import pytest
 import inspect
 
+from textwrap import dedent
 from django.core.management import call_command
 from django.db.models import Model
 from django.test import override_settings
@@ -13,11 +12,20 @@ from django.test import override_settings
 from django_extensions.management.commands import shell_plus
 
 
-@pytest.mark.skipif(django.VERSION < (2, 0), reason="This test works only on Django greater than 2.0.0")
+def test_shell_plus_command(capsys):
+    script = dedent('''\
+        def _fn(x): return x * 2
+        print([_fn(i) for i in range(10)])
+        ''')
+    call_command("shell_plus", "--command=" + script)
+    out, err = capsys.readouterr()
+
+    assert out.rstrip().endswith(repr([i * 2 for i in range(10)]))
+
+
 @pytest.mark.django_db()
 @override_settings(SHELL_PLUS_SQLPARSE_ENABLED=False, SHELL_PLUS_PYGMENTS_ENABLED=False)
 def test_shell_plus_print_sql(capsys):
-    out = six.StringIO()
     try:
         from django.db import connection
         from django.db.backends import utils
@@ -33,6 +41,39 @@ def test_shell_plus_print_sql(capsys):
     assert re.search(r"SELECT\s+.+\s+FROM\s+.auth_user.\s+LIMIT\s+1", out)
 
 
+@pytest.mark.django_db()
+@override_settings(SHELL_PLUS_SQLPARSE_ENABLED=False, SHELL_PLUS_PYGMENTS_ENABLED=False)
+def test_shell_plus_print_sql_truncate(capsys):
+    try:
+        from django.db import connection
+        from django.db.backends import utils
+        CursorDebugWrapper = utils.CursorDebugWrapper
+        force_debug_cursor = True if connection.force_debug_cursor else False
+        call_command("shell_plus", "--plain", "--print-sql", "--truncate-sql=0", "--command=User.objects.all().exists()")
+    finally:
+        utils.CursorDebugWrapper = CursorDebugWrapper
+        connection.force_debug_cursor = force_debug_cursor
+
+    out, err = capsys.readouterr()
+
+    assert re.search(r"SELECT\s+.+\s+FROM\s+.auth_user.\s+LIMIT\s+1", out)
+
+    try:
+        from django.db import connection
+        from django.db.backends import utils
+        CursorDebugWrapper = utils.CursorDebugWrapper
+        force_debug_cursor = True if connection.force_debug_cursor else False
+        call_command("shell_plus", "--plain", "--print-sql", "--truncate-sql=4", "--command=User.objects.all().exists()")
+    finally:
+        utils.CursorDebugWrapper = CursorDebugWrapper
+        connection.force_debug_cursor = force_debug_cursor
+
+    out, err = capsys.readouterr()
+
+    assert re.search(r"SELE", out)
+    assert not re.search(r"SELEC", out)
+
+
 def test_shell_plus_plain_startup():
     command = shell_plus.Command()
     command.tests_mode = True
