@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 import os
-import six
-from distutils.version import LooseVersion
 
 import pytest
-from django import get_version
+from unittest.mock import patch
+
 from django.core.management import CommandError, call_command
 from django.db import models
 from django.test import TestCase, override_settings
@@ -12,11 +11,6 @@ from tests import testapp_with_appconfig
 
 MIGRATIONS_DIR = os.path.join(testapp_with_appconfig.__path__[0], 'migrations')
 
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch
-
 
 @override_settings(MIGRATION_MODULES={'testapp_with_appconfig': 'tests.testapp_with_appconfig.migrations'})
 class BaseDeleteSquashedMigrationsTestCase(TestCase):
@@ -41,24 +35,18 @@ class BaseDeleteSquashedMigrationsTestCase(TestCase):
 
 
 @pytest.mark.xfail
-@pytest.mark.skipif(
-    LooseVersion(get_version()) <= LooseVersion('2.0.0'),
-    reason="This test works only on Django greater than 2.0.0",
-)
 class DeleteSquashedMigrationsExceptionsTests(BaseDeleteSquashedMigrationsTestCase):
     """Tests for delete_squashed_migrations command exceptions."""
 
     def test_should_raise_CommandError_if_app_does_not_have_migrations(self):
-        with six.assertRaisesRegex(
-                self,
+        with self.assertRaisesRegex(
                 CommandError,
                 r"App 'testapp_with_no_models_file' does not have migrations \(so delete_squashed_migrations on it makes no sense\)"):
 
             call_command('delete_squashed_migrations', 'testapp_with_no_models_file')
 
     def test_should_raise_CommandEror_if_migration_is_not_squashed(self):
-        with six.assertRaisesRegex(
-                self,
+        with self.assertRaisesRegex(
                 CommandError,
                 "The migration testapp_with_appconfig 0001_initial is not a squashed migration."):
 
@@ -76,8 +64,7 @@ class DeleteSquashedMigrationsExceptionsTests(BaseDeleteSquashedMigrationsTestCa
         call_command('makemigrations', 'testapp_with_appconfig')
         call_command('squashmigrations', 'testapp_with_appconfig', '0002', '--noinput')
 
-        with six.assertRaisesRegex(
-                self,
+        with self.assertRaisesRegex(
                 CommandError,
                 "More than one migration matches '0001' in app 'testapp_with_appconfig'. Please be more specific."):
 
@@ -93,28 +80,26 @@ class DeleteSquashedMigrationsExceptionsTests(BaseDeleteSquashedMigrationsTestCa
 
         call_command('makemigrations', 'testapp_with_appconfig')
 
-        with six.assertRaisesRegex(
-                self,
+        with self.assertRaisesRegex(
                 CommandError,
                 "Cannot find a squashed migration in app 'testapp_with_appconfig'."):
 
             call_command('delete_squashed_migrations', 'testapp_with_appconfig')
 
     def test_should_raise_CommandEror_if_squashed_migration_not_foundee(self):
-        with six.assertRaisesRegex(
-                self,
+        with self.assertRaisesRegex(
                 CommandError,
                 "Cannot find a migration matching '0002' from app 'testapp_with_appconfig'."):
 
             call_command('delete_squashed_migrations', 'testapp_with_appconfig',
                          '0002')
 
+    def test_should_raise_CommandError_when_database_does_not_exist(self):
+        with self.assertRaisesRegex(CommandError, 'Unknown database non-existing_database'):
+            call_command('delete_squashed_migrations', '--database=non-existing_database')
+
 
 @pytest.mark.xfail
-@pytest.mark.skipif(
-    LooseVersion(get_version()) <= LooseVersion('2.0.0'),
-    reason="This test works only on Django greater than 2.0.0",
-)
 class DeleteSquashedMigrationsTests(BaseDeleteSquashedMigrationsTestCase):
     """Tests for delete_squashed_migrations command."""
 
