@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import six
 from importlib import import_module
 from io import StringIO
 
@@ -8,17 +7,14 @@ from django.contrib.auth import get_user_model
 from django.core.management import CommandError, call_command
 from django.test import TestCase
 
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch
+from unittest.mock import patch
 
 
 class PrintUserForSessionExceptionsTests(TestCase):
     """Test if print_user_for_session command raises exception."""
 
     def test_should_raise_CommandError_if_session_key_contains_exclamination_mark(self):
-        with six.assertRaisesRegex(self, CommandError, 'malformed session key'):
+        with self.assertRaisesRegex(CommandError, 'malformed session key'):
             call_command('print_user_for_session', 'l6hxnwblpvrfu8bohelmqjj4soyo2r!?')
 
 
