@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
 from django.core.management import call_command
 from django.test import TestCase
-from six import StringIO
+from io import StringIO
 
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch
+from unittest.mock import patch
 
 
 class FindTemplateTests(TestCase):
